#
# spec file for package ghc-haskell-src-exts
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name haskell-src-exts
# no useful debuginfo for Haskell packages without C sources
%global debug_package %{nil}
%bcond_with tests
Name:           ghc-haskell-src-exts
Version:        1.17.1
Release:        1.3
Summary:        Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
License:        BSD-3-Clause
Group:          Development/Libraries/Other
Url:            http://hackage.haskell.org/package/%{pkg_name}
Source0:        http://hackage.haskell.org/packages/archive/%{pkg_name}/%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-cpphs-devel
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  happy
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-smallcheck-devel
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
BuildRequires:  ghc-tasty-smallcheck-devel
%endif

%description
Haskell-Source with Extensions (HSE, haskell-src-exts) is an extension of the
standard haskell-src package, and handles most registered syntactic extensions
to Haskell, including:

* Multi-parameter type classes with functional dependencies

* Indexed type families (including associated types)

* Empty data declarations

* GADTs

* Implicit parameters

* Template Haskell

and a few more. All extensions implemented in GHC are supported. Apart from
these standard extensions, it also handles regular patterns as per the HaRP
extension as well as HSX-style embedded XML syntax.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%{ghc_lib_build}

%install
%{ghc_lib_install}

%check
%if %{with tests}
%{cabal} test
%endif

%post devel
%{ghc_pkg_recache}

%postun devel
%{ghc_pkg_recache}

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)

%changelog
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 0.17.1
  * Fix bug in parsing view patterns (#284)
  * Replaced VarA with AppA in Asst (#168).
  * Promoted list/tuple members changed from Promoted to Type (#162).
  * Update PatBind, Match, and Alt from containing Binds to Maybe Binds to
  distinguish between empty where clauses and where clauses with no
  binds (#244).
  * Add RoleAnnotDecl and Role to support Role annotations (#215).
  * Move NameSpace field from EVar/IVar to EAbs/IAbs.
  * Add standalone parsers for ImportDecl.
  * Fix pretty-printer bugs for HaRP (#160).
  * Insert parentheses when pretty-printing non-atomic bang types (#169).
  * Un-reverse confusion of left and right arrow (#175).
  * Prettyprint option pragmas like 1.15 (#172).
  * Conditionally insert lines when pretty-printing declarations (#171).
  * Distinguish deriving (Show) from deriving Show (#189).
  * Allow parsing of unicode subscript and superscript functions (#173).
  * Pretty print unboxed tuples with spaces (#193).
  * Improve performance when parsing long extension lists (#200).
  * Properly pretty print constructor and class operators (#204).
  * Read Haskell source files as UTF-8 (#223).
  * Fix ExplicitNamespaces parsing (#216).
  * PolyKinds implies KindSignatures (#220).
  * Preserve location information for infix binds (#205).
  * Preserve positional information in checkPattern (#231).
  * Maintain correct line numbers when parsing multiline GHC_OPTIONS (#218).
  * Correctly parse "*" with TypeOperators (#81).
  * Export the "pretty" method (#222).
  * Add javascript calling convention for foreign imports (#236).
  * Add non-greedy parsers for module heads (#191).
  * Add a flag to disable arity checking when parsing (#260).
  * Parse "-" in type signatures (#206).
  * Add support for type wildcards and expression holes (#252).
  * Add support for Pattern Synonyms (#197).
  * Bump the happy lower bound (#250).
  * Make test suite pass on GHC 7.12 (#224).
  * Support linking Haddock comments to AST nodes (#213).
  * Parse multiline LANGUAGE pragmas (#217).
  * Parse trailing where (#25).
  * Parse modules starting with pragmas and indented
  "module" keyword (#122).
  * Use pretty-show to get human readable test outputs.
  * Respect fixity declarations inside where/let/class in
  `applyFixities` (#212).
  * Correctly parse the combination of view patterns and bang patterns. (#276)
* Wed Apr 29 2015 mimi.vx@gmail.com
- add _constraints file for ppc64le
* Sat Nov 22 2014 mimi.vx@gmail.com
- add group to devel section
* Fri Nov 21 2014 mimi.vx@gmail.com
- initial commit
